# The lsb release used in the tarball name
%global lsb 1lsb3.2
# Not defined on el6
%{!?_cups_serverbin: %global _cups_serverbin %(/usr/bin/cups-config --serverbin)}

Name:           epson-inkjet-printer-escpr
Summary:        Drivers for Epson inkjet printers
Group:          Applications/System
Epoch:          1
Version:        1.6.13
Release:        3.%{lsb}%{?dist}
License:        GPLv2+
URL:            http://download.ebz.epson.net/dsc/search/01/search/?OSC=LX
# Download address is garbled on web page
Source0:        https://download3.ebz.epson.net/dsc/f/03/00/05/55/39/d16f39e5f8953e033f6f38083b38c50c543b891c/epson-inkjet-printer-escpr-%{version}-%{lsb}.tar.gz
# Fix includes
Patch0:         epson-inkjet-printer-escpr-inc.patch
# Patch from Arch Linux
# https://aur.archlinux.org/packages/epson-inkjet-printer-escpr/
Patch1:         epson-inkjet-printer-escpr-filter.patch

BuildRequires:  autoconf
BuildRequires:  chrpath
BuildRequires:  cups-devel
BuildRequires:  libjpeg-devel

%if 0%{?fedora} >= 21
# For automatic detection of printer drivers
BuildRequires:  python3-cups
%endif
%if 0%{?rhel} == 7
# For automatic detection of printer drivers
BuildRequires:  python-cups
%endif
%if 0%{?rhel} == 6
# For dir ownership
Requires:       cups
%else
# For dir ownership
Requires:       cups-filesystem
# So that automatic printer driver installation works
BuildRequires:  python-cups
%endif

%description
This package contains drivers for Epson Inkjet printers that use 
the New Generation Epson Printer Control Language.

For a detailed list of supported printers, please refer to
http://avasys.jp/english/linux_e/

%prep
%setup -q 
%patch0 -p1 -b .inc
%patch1 -p1 -b .filter
# Fix permissions
find . -name \*.h -exec chmod 644 {} \;
find . -name \*.c -exec chmod 644 {} \;
for f in README README.ja COPYING AUTHORS NEWS; do
 chmod 644 $f
done

%build
autoconf
%configure --disable-static --enable-shared --disable-rpath
# SMP make doesn't work
#make %{?_smp_mflags}
make

%install
make install DESTDIR=%{buildroot} CUPS_PPD_DIR=%{_datadir}/ppd/Epson
# Get rid of .la files
rm -f %{buildroot}%{_libdir}/*.la
# Compress ppd files
for ppd in %{buildroot}%{_datadir}/ppd/Epson/epson-inkjet-printer-escpr/*.ppd; do
 gzip $ppd
done
# Get rid of rpath
chrpath --delete %{buildroot}%{_cups_serverbin}/filter/epson-escpr
# Copy documentation
cp -a README README.ja COPYING AUTHORS NEWS ..

# Get rid of .so file, since no headers are installed.
rm %{buildroot}%{_libdir}/libescpr.so

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc README README.ja COPYING AUTHORS NEWS
%{_cups_serverbin}/filter/epson-*
%{_datadir}/ppd/Epson/
%{_libdir}/libescpr.so.*

%changelog
* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.6.13-3.1lsb3.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.6.13-2.1lsb3.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Thu Jun 22 2017 Susi Lehtola <jussilehtola@fedoraproject.org> - 1:1.6.13-1.1lsb3.2
- Update to 1.6.13.

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.6.10-3.1lsb3.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Nov 30 2016 Susi Lehtola <jussilehtola@fedoraproject.org> - 1:1.6.10-2.1lsb3.2
- Fix FTBFS in rawhide.
- Add patch that fixes crashes (BZ #1400346).

* Thu Nov 24 2016 Susi Lehtola <jussilehtola@fedoraproject.org> - 1:1.6.10-1.1lsb3.2
- Update to 1.6.10.

* Sun Apr 24 2016 Susi Lehtola <jussilehtola@fedoraproject.org> - 1:1.5.2-3.1lsb3.2
- Roll back to 1.5.2 due to serious bug in 1.6.x series.

* Sun Apr 24 2016 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.6.5-1.1lsb3.2
- Update to 1.6.5.

* Thu Mar 31 2016 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.6.4-1.1lsb3.2
- Make sure driver provides are autodetected (BZ #1323033).
- Update to 1.6.4.

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.2-2.1lsb3.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Sep 21 2015 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.5.2-1.1lsb3.2
- Update to 1.5.2.

* Tue Aug 11 2015 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.5.0-1.1lsb3.2
- Update to 1.5.0.

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-2.1lsb3.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Oct 30 2014 Orion Poplawski <orion@cora.nwra.com> - 1.4.3-1.1lsb3.2
- Update to 1.4.3

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-3.1lsb3.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-2.1lsb3.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Jan 07 2014 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.3.1-1.1lsb3.2
- Added BR: python-cups (BZ #1049528).
- Update to 1.3.1.

* Sun Nov 03 2013 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.3.0-1.1lsb3.2
- Update to 1.3.0.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.3-2.1lsb3.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 23 2013 Orion Poplawski <orion@cora.nwra.com> - 1.2.3-1.1lsb3.2
- Update to 1.2.3
- spec cleanup

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.2-2.1lsb3.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1-2.1lsb3.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jun 16 2012 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.1.1-1.1lsb3.2
- Update to 1.1.1.

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.0-2.1lsb3.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Sep 30 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.1.0-1.1lsb3.2
- Update to 1.1.0.

* Sun Aug 28 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.0.4-3.1lsb3.2
- No sense in shipping .so file without headers; dropped -devel.

* Wed Jul 13 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.0.4-2.1lsb3.2
- Get rid of rpath.

* Mon Jul 11 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.0.4-1.1lsb3.2
- First release.
